//
// Beta-Binomial distribution
//
data {
  int<lower=0> N;
  int<lower=0> x[N];
  int<lower=1> n[N];
  int<lower=0> N_new;
  int<lower=1> n_new[N_new];
}

parameters {
  real<lower=0,upper=1> p[N];
  real<lower=0,upper=1> phi; // = alpha/(alpha+beta)
  real<lower=0.1> lambda; // = alpha+beta
}

transformed parameters {
  real<lower=0> alpha = lambda * phi;
  real<lower=0> beta = lambda * (1-phi);
}

model {
//  phi ~ beta(1,1); // uniform
//  lambda ~ pareto(0.1, 1.5); // Gelman2013 Chap5
  p ~ beta(alpha, beta);
  x ~ binomial(n, p);
//  x ~ beta_binomial(n, alpha, beta);
}

generated quantities {
  int<lower=0> x_rep[N_new];
  x_rep = beta_binomial_rng(n_new, alpha, beta);
}
